package dev.fitko.fitconnect.client.factory;

import dev.fitko.fitconnect.api.config.ApplicationConfig;
import dev.fitko.fitconnect.api.config.Environment;
import dev.fitko.fitconnect.api.config.EnvironmentName;
import dev.fitko.fitconnect.api.config.SenderConfig;
import dev.fitko.fitconnect.api.config.SubscriberConfig;
import dev.fitko.fitconnect.api.exceptions.InitializationException;
import org.junit.jupiter.api.Test;

import java.util.Map;

import static org.junit.jupiter.api.Assertions.assertNotNull;
import static org.junit.jupiter.api.Assertions.assertThrows;

class ClientFactoryTest {

    @Test
    void testMissingConfiguration() {
        assertThrows(InitializationException.class, ClientFactory::senderClient);
        assertThrows(InitializationException.class, ClientFactory::subscriberClient);
    }

    @Test
    void testSenderClientConstruction() {

        final var envName = new EnvironmentName("DEV");
        final var environments = Map.of(envName, new Environment("https://auth", "", true));

        final var sender = new SenderConfig("123", "abc");

        final var senderConfig = ApplicationConfig.builder()
                .httpProxyHost("https://proxy.fitco.de")
                .httpProxyPort(0)
                .environments(environments)
                .senderConfig(sender)
                .activeEnvironment(envName)
                .build();

        assertNotNull(ClientFactory.senderClient(senderConfig));
    }

    @Test
    void testSubscriberClientConstruction() {

        final var envName = new EnvironmentName("DEV");
        final var environments = Map.of(envName, new Environment("https://auth", "", true));

        final var subscriber = SubscriberConfig.builder()
                .clientSecret("123")
                .clientSecret("abc")
                .privateDecryptionKeyPath("src/test/resources/private_decryption_test_key.json")
                .privateSigningKeyPath("src/test/resources/private_test_signing_key.json")
                .build();

        final var subscriberConfig = ApplicationConfig.builder()
                .httpProxyHost("https://proxy.fitco.de")
                .httpProxyPort(0)
                .environments(environments)
                .subscriberConfig(subscriber)
                .activeEnvironment(envName)
                .build();

        assertNotNull(ClientFactory.subscriberClient(subscriberConfig));
    }
}